@@ -3,7 +3,7 @@ package Bundle::WWW::Scraper::ISBN::Drivers;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = "1.04";
+$VERSION = "1.05";
 
 1;
 
@@ -41,6 +41,8 @@ WWW::Scraper::ISBN::AmazonUK_Driver
 
 WWW::Scraper::ISBN::AmazonUS_Driver
 
+WWW::Scraper::ISBN::BarnesNoble_Driver
+
 WWW::Scraper::ISBN::BookDepository_Driver
 
 WWW::Scraper::ISBN::Booktopia_Driver
@@ -95,6 +97,8 @@ WWW::Scraper::ISBN::TWYlib_Driver
 
 WWW::Scraper::ISBN::Wheelers_Driver
 
+WWW::Scraper::ISBN::WHSmith_Driver
+
 WWW::Scraper::ISBN::WordPower_Driver
 
 WWW::Scraper::ISBN::Yahoo_Driver
